summaryrefslogtreecommitdiff
path: root/tools
diff options
context:
space:
mode:
authorHans Kristian Rosbach <hk-git@circlestorm.org>2021-05-10 16:48:29 +0200
committerHans Kristian Rosbach <hk-github@circlestorm.org>2021-06-13 20:55:01 +0200
commitcf9127a2311eda5803ff9a84a8ce4089163034b8 (patch)
tree9285160bfbae7a4b8e6a24a0e845015ee0b25b9b /tools
parente56238cbc4433b71b75f08deac35addb8426fef6 (diff)
downloadProject-Tick-cf9127a2311eda5803ff9a84a8ce4089163034b8.tar.gz
Project-Tick-cf9127a2311eda5803ff9a84a8ce4089163034b8.zip
Separate MIN_MATCH into STD_MIN_MATCH and WANT_MIN_MATCH
Rename MAX_MATCH to STD_MAX_MATCH
Diffstat (limited to 'tools')
-rw-r--r--tools/maketrees.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/tools/maketrees.c b/tools/maketrees.c
index c648a650c8..282bddc2e5 100644
--- a/tools/maketrees.c
+++ b/tools/maketrees.c
@@ -23,11 +23,11 @@ static unsigned char dist_code[DIST_CODE_LEN];
* the last 256 values correspond to the top 8 bits of the 15 bit distances.
*/
-static unsigned char length_code[MAX_MATCH-MIN_MATCH+1];
-/* length code for each normalized match length (0 == MIN_MATCH) */
+static unsigned char length_code[STD_MAX_MATCH-STD_MIN_MATCH+1];
+/* length code for each normalized match length (0 == STD_MIN_MATCH) */
static int base_length[LENGTH_CODES];
/* First normalized length for each code (0 = MIN_MATCH) */
static int base_dist[D_CODES];
/* First normalized distance for each code (0 = distance of 1) */
@@ -121,9 +121,9 @@ static void gen_trees_header() {
printf("%2u%s", dist_code[i], SEPARATOR(i, DIST_CODE_LEN-1, 20));
}
- printf("const unsigned char Z_INTERNAL zng_length_code[MAX_MATCH-MIN_MATCH+1] = {\n");
- for (i = 0; i < MAX_MATCH-MIN_MATCH+1; i++) {
- printf("%2u%s", length_code[i], SEPARATOR(i, MAX_MATCH-MIN_MATCH, 20));
+ printf("const unsigned char Z_INTERNAL zng_length_code[STD_MAX_MATCH-STD_MIN_MATCH+1] = {\n");
+ for (i = 0; i < STD_MAX_MATCH-STD_MIN_MATCH+1; i++) {
+ printf("%2u%s", length_code[i], SEPARATOR(i, STD_MAX_MATCH-STD_MIN_MATCH, 20));
}
printf("Z_INTERNAL const int base_length[LENGTH_CODES] = {\n");
@@ -23,11 +23,11 @@ static unsigned char dist_code[DIST_CODE_LEN];
static int base_length[LENGTH_CODES];
-/* First normalized length for each code (0 = MIN_MATCH) */
+/* First normalized length for each code (0 = STD_MIN_MATCH) */
static int base_dist[D_CODES];
/* First normalized distance for each code (0 = distance of 1) */